/* Collection.c generated by valac 0.56.19, the Vala compiler
 * generated from Collection.vala, do not modify */

#include <adwaita.h>
#include <glib-object.h>
#include <stdlib.h>
#include <string.h>
#include <glib.h>
#include <gtk/gtk.h>
#include <pango/pango.h>
#include <glib/gi18n-lib.h>
#include <gee.h>
#include <gio/gio.h>
#include <libsoup/soup.h>
#include <json-glib/json-glib.h>
#include <float.h>
#include <math.h>

#if !defined(VALA_STRICT_C)
#if !defined(__clang__) && defined(__GNUC__) && (__GNUC__ >= 14)
#pragma GCC diagnostic warning "-Wincompatible-pointer-types"
#elif defined(__clang__) && (__clang_major__ >= 16)
#pragma clang diagnostic ignored "-Wincompatible-function-pointer-types"
#pragma clang diagnostic ignored "-Wincompatible-pointer-types"
#endif
#endif
#if !defined(VALA_EXTERN)
#if defined(_MSC_VER)
#define VALA_EXTERN __declspec(dllexport) extern
#elif __GNUC__ >= 4
#define VALA_EXTERN __attribute__((visibility("default"))) extern
#else
#define VALA_EXTERN extern
#endif
#endif

#define TUBA_DIALOGS_TYPE_COLLECTION (tuba_dialogs_collection_get_type ())
#define TUBA_DIALOGS_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_DIALOGS_TYPE_COLLECTION, TubaDialogsCollection))
#define TUBA_DIALOGS_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_DIALOGS_TYPE_COLLECTION, TubaDialogsCollectionClass))
#define TUBA_DIALOGS_IS_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_DIALOGS_TYPE_COLLECTION))
#define TUBA_DIALOGS_IS_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_DIALOGS_TYPE_COLLECTION))
#define TUBA_DIALOGS_COLLECTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_DIALOGS_TYPE_COLLECTION, TubaDialogsCollectionClass))

typedef struct _TubaDialogsCollection TubaDialogsCollection;
typedef struct _TubaDialogsCollectionClass TubaDialogsCollectionClass;
typedef struct _TubaDialogsCollectionPrivate TubaDialogsCollectionPrivate;
enum  {
	TUBA_DIALOGS_COLLECTION_0_PROPERTY,
	TUBA_DIALOGS_COLLECTION_NUM_PROPERTIES
};
static GParamSpec* tuba_dialogs_collection_properties[TUBA_DIALOGS_COLLECTION_NUM_PROPERTIES];
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_free0(var) (var = (g_free (var), NULL))

#define TUBA_TYPE_ENTITY (tuba_entity_get_type ())
#define TUBA_ENTITY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_ENTITY, TubaEntity))
#define TUBA_ENTITY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_TYPE_ENTITY, TubaEntityClass))
#define TUBA_IS_ENTITY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_ENTITY))
#define TUBA_IS_ENTITY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_TYPE_ENTITY))
#define TUBA_ENTITY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_TYPE_ENTITY, TubaEntityClass))

typedef struct _TubaEntity TubaEntity;
typedef struct _TubaEntityClass TubaEntityClass;

#define TUBA_API_TYPE_COLLECTION (tuba_api_collection_get_type ())
#define TUBA_API_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_API_TYPE_COLLECTION, TubaAPICollection))
#define TUBA_API_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_API_TYPE_COLLECTION, TubaAPICollectionClass))
#define TUBA_API_IS_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_API_TYPE_COLLECTION))
#define TUBA_API_IS_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_API_TYPE_COLLECTION))
#define TUBA_API_COLLECTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_API_TYPE_COLLECTION, TubaAPICollectionClass))

typedef struct _TubaAPICollection TubaAPICollection;
typedef struct _TubaAPICollectionClass TubaAPICollectionClass;

#define TUBA_API_COLLECTION_TYPE_TAG (tuba_api_collection_tag_get_type ())
#define TUBA_API_COLLECTION_TAG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_API_COLLECTION_TYPE_TAG, TubaAPICollectionTag))
#define TUBA_API_COLLECTION_TAG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_API_COLLECTION_TYPE_TAG, TubaAPICollectionTagClass))
#define TUBA_API_COLLECTION_IS_TAG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_API_COLLECTION_TYPE_TAG))
#define TUBA_API_COLLECTION_IS_TAG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_API_COLLECTION_TYPE_TAG))
#define TUBA_API_COLLECTION_TAG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_API_COLLECTION_TYPE_TAG, TubaAPICollectionTagClass))

typedef struct _TubaAPICollectionTag TubaAPICollectionTag;
typedef struct _TubaAPICollectionTagClass TubaAPICollectionTagClass;

#define TUBA_WIDGETS_TYPE_MARKUP_VIEW (tuba_widgets_markup_view_get_type ())
#define TUBA_WIDGETS_MARKUP_VIEW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_WIDGETS_TYPE_MARKUP_VIEW, TubaWidgetsMarkupView))
#define TUBA_WIDGETS_MARKUP_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_WIDGETS_TYPE_MARKUP_VIEW, TubaWidgetsMarkupViewClass))
#define TUBA_WIDGETS_IS_MARKUP_VIEW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_WIDGETS_TYPE_MARKUP_VIEW))
#define TUBA_WIDGETS_IS_MARKUP_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_WIDGETS_TYPE_MARKUP_VIEW))
#define TUBA_WIDGETS_MARKUP_VIEW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_WIDGETS_TYPE_MARKUP_VIEW, TubaWidgetsMarkupViewClass))

typedef struct _TubaWidgetsMarkupView TubaWidgetsMarkupView;
typedef struct _TubaWidgetsMarkupViewClass TubaWidgetsMarkupViewClass;

#define TUBA_API_COLLECTION_TYPE_ITEM (tuba_api_collection_item_get_type ())
#define TUBA_API_COLLECTION_ITEM(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_API_COLLECTION_TYPE_ITEM, TubaAPICollectionItem))
#define TUBA_API_COLLECTION_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_API_COLLECTION_TYPE_ITEM, TubaAPICollectionItemClass))
#define TUBA_API_COLLECTION_IS_ITEM(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_API_COLLECTION_TYPE_ITEM))
#define TUBA_API_COLLECTION_IS_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_API_COLLECTION_TYPE_ITEM))
#define TUBA_API_COLLECTION_ITEM_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_API_COLLECTION_TYPE_ITEM, TubaAPICollectionItemClass))

typedef struct _TubaAPICollectionItem TubaAPICollectionItem;
typedef struct _TubaAPICollectionItemClass TubaAPICollectionItemClass;

#define TUBA_WIDGETS_TYPE_ACCOUNT_ROW (tuba_widgets_account_row_get_type ())
#define TUBA_WIDGETS_ACCOUNT_ROW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_WIDGETS_TYPE_ACCOUNT_ROW, TubaWidgetsAccountRow))
#define TUBA_WIDGETS_ACCOUNT_ROW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_WIDGETS_TYPE_ACCOUNT_ROW, TubaWidgetsAccountRowClass))
#define TUBA_WIDGETS_IS_ACCOUNT_ROW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_WIDGETS_TYPE_ACCOUNT_ROW))
#define TUBA_WIDGETS_IS_ACCOUNT_ROW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_WIDGETS_TYPE_ACCOUNT_ROW))
#define TUBA_WIDGETS_ACCOUNT_ROW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_WIDGETS_TYPE_ACCOUNT_ROW, TubaWidgetsAccountRowClass))

typedef struct _TubaWidgetsAccountRow TubaWidgetsAccountRow;
typedef struct _TubaWidgetsAccountRowClass TubaWidgetsAccountRowClass;
typedef struct _Block20Data Block20Data;
#define _g_hash_table_unref0(var) ((var == NULL) ? NULL : (var = (g_hash_table_unref (var), NULL)))

#define TUBA_TYPE_REQUEST_V2 (tuba_request_v2_get_type ())
#define TUBA_REQUEST_V2(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_REQUEST_V2, TubaRequestV2))
#define TUBA_REQUEST_V2_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_TYPE_REQUEST_V2, TubaRequestV2Class))
#define TUBA_IS_REQUEST_V2(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_REQUEST_V2))
#define TUBA_IS_REQUEST_V2_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_TYPE_REQUEST_V2))
#define TUBA_REQUEST_V2_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_TYPE_REQUEST_V2, TubaRequestV2Class))

typedef struct _TubaRequestV2 TubaRequestV2;
typedef struct _TubaRequestV2Class TubaRequestV2Class;
typedef enum  {
	TUBA_REQUEST_V2_METHOD_GET,
	TUBA_REQUEST_V2_METHOD_POST,
	TUBA_REQUEST_V2_METHOD_PUT,
	TUBA_REQUEST_V2_METHOD_DELETE,
	TUBA_REQUEST_V2_METHOD_PATCH
} TubaRequestV2Method;

#define TUBA_REQUEST_V2_TYPE_METHOD (tuba_request_v2_method_get_type ())

#define TUBA_TYPE_ACCOUNT_STORE (tuba_account_store_get_type ())
#define TUBA_ACCOUNT_STORE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_ACCOUNT_STORE, TubaAccountStore))
#define TUBA_ACCOUNT_STORE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_TYPE_ACCOUNT_STORE, TubaAccountStoreClass))
#define TUBA_IS_ACCOUNT_STORE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_ACCOUNT_STORE))
#define TUBA_IS_ACCOUNT_STORE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_TYPE_ACCOUNT_STORE))
#define TUBA_ACCOUNT_STORE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_TYPE_ACCOUNT_STORE, TubaAccountStoreClass))

typedef struct _TubaAccountStore TubaAccountStore;
typedef struct _TubaAccountStoreClass TubaAccountStoreClass;

#define TUBA_API_TYPE_ACCOUNT (tuba_api_account_get_type ())
#define TUBA_API_ACCOUNT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_API_TYPE_ACCOUNT, TubaAPIAccount))
#define TUBA_API_ACCOUNT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_API_TYPE_ACCOUNT, TubaAPIAccountClass))
#define TUBA_API_IS_ACCOUNT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_API_TYPE_ACCOUNT))
#define TUBA_API_IS_ACCOUNT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_API_TYPE_ACCOUNT))
#define TUBA_API_ACCOUNT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_API_TYPE_ACCOUNT, TubaAPIAccountClass))

typedef struct _TubaAPIAccount TubaAPIAccount;
typedef struct _TubaAPIAccountClass TubaAPIAccountClass;

#define TUBA_TYPE_INSTANCE_ACCOUNT (tuba_instance_account_get_type ())
#define TUBA_INSTANCE_ACCOUNT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_INSTANCE_ACCOUNT, TubaInstanceAccount))
#define TUBA_INSTANCE_ACCOUNT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_TYPE_INSTANCE_ACCOUNT, TubaInstanceAccountClass))
#define TUBA_IS_INSTANCE_ACCOUNT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_INSTANCE_ACCOUNT))
#define TUBA_IS_INSTANCE_ACCOUNT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_TYPE_INSTANCE_ACCOUNT))
#define TUBA_INSTANCE_ACCOUNT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_TYPE_INSTANCE_ACCOUNT, TubaInstanceAccountClass))

typedef struct _TubaInstanceAccount TubaInstanceAccount;
typedef struct _TubaInstanceAccountClass TubaInstanceAccountClass;

#define TUBA_TYPE_OOPSIE (tuba_oopsie_get_type ())
typedef void (*TubaNetworkNodeCallback) (JsonNode* node, gpointer user_data, GError** error);

#define TUBA_API_TYPE_RELATIONSHIP (tuba_api_relationship_get_type ())
#define TUBA_API_RELATIONSHIP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_API_TYPE_RELATIONSHIP, TubaAPIRelationship))
#define TUBA_API_RELATIONSHIP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_API_TYPE_RELATIONSHIP, TubaAPIRelationshipClass))
#define TUBA_API_IS_RELATIONSHIP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_API_TYPE_RELATIONSHIP))
#define TUBA_API_IS_RELATIONSHIP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_API_TYPE_RELATIONSHIP))
#define TUBA_API_RELATIONSHIP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_API_TYPE_RELATIONSHIP, TubaAPIRelationshipClass))

typedef struct _TubaAPIRelationship TubaAPIRelationship;
typedef struct _TubaAPIRelationshipClass TubaAPIRelationshipClass;
typedef struct _TubaDialogsCollectionGatherAccountsData TubaDialogsCollectionGatherAccountsData;

struct _TubaDialogsCollection {
	AdwDialog parent_instance;
	TubaDialogsCollectionPrivate * priv;
};

struct _TubaDialogsCollectionClass {
	AdwDialogClass parent_class;
};

struct _TubaDialogsCollectionPrivate {
	AdwHeaderBar* headerbar;
	AdwPreferencesGroup* member_group;
	AdwPreferencesGroup* author_group;
	AdwToastOverlay* toast_overlay;
	gchar* collection_url;
};

struct _Block20Data {
	int _ref_count_;
	TubaDialogsCollection* self;
	gchar** accounts_arr;
	gint accounts_arr_length1;
	gint _accounts_arr_size_;
	gchar** account_ids;
	gint account_ids_length1;
	gint _account_ids_size_;
	GHashTable* states;
	TubaWidgetsAccountRow** widgets;
	gint widgets_length1;
	gint _widgets_size_;
	gboolean did_author;
	TubaAPICollection* collection;
	gpointer _async_data_;
};

typedef enum  {
	TUBA_OOPSIE_USER,
	TUBA_OOPSIE_PARSING,
	TUBA_OOPSIE_INSTANCE,
	TUBA_OOPSIE_INTERNAL,
	TUBA_OOPSIE_HTTP_401 = 401,
	TUBA_OOPSIE_HTTP_403 = 403,
	TUBA_OOPSIE_HTTP_404 = 404,
	TUBA_OOPSIE_HTTP_410 = 410,
	TUBA_OOPSIE_HTTP_422 = 422,
	TUBA_OOPSIE_HTTP_429 = 429,
	TUBA_OOPSIE_HTTP_500 = 500,
	TUBA_OOPSIE_HTTP_503 = 503
} TubaOopsie;
#define TUBA_OOPSIE tuba_oopsie_quark ()

struct _TubaDialogsCollectionGatherAccountsData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GTask* _async_result;
	TubaDialogsCollection* self;
	TubaAPICollection* collection;
	Block20Data* _data20_;
	const gchar* _tmp0_;
	const gchar* _tmp1_;
	const gchar* _tmp2_;
	gchar* _tmp3_;
	gchar** _tmp4_;
	const gchar* _tmp5_;
	const gchar* _tmp6_;
	gchar* _tmp7_;
	gchar** _tmp8_;
	GHashFunc _tmp9_;
	GEqualFunc _tmp10_;
	GHashTable* _tmp11_;
	GeeArrayList* _tmp12_;
	GeeArrayList* _tmp13_;
	TubaRequestV2* req;
	gchar** _tmp14_;
	gint _tmp14__length1;
	gchar* _tmp15_;
	gchar* _tmp16_;
	const gchar* _tmp17_;
	gchar* _tmp18_;
	gchar* _tmp19_;
	TubaAccountStore* _tmp20_;
	TubaInstanceAccount* _tmp21_;
	TubaInstanceAccount* _tmp22_;
	TubaInstanceAccount* _tmp23_;
	TubaRequestV2* _tmp24_;
	TubaRequestV2* _tmp25_;
	GInputStream* in_stream;
	TubaRequestV2* _tmp26_;
	GInputStream* _tmp27_;
	TubaWidgetsAccountRow** _tmp28_;
	JsonParser* parser;
	GInputStream* _tmp29_;
	JsonParser* _tmp30_;
	JsonParser* _tmp31_;
	GeeHashMap* relationships;
	gchar** _tmp32_;
	gint _tmp32__length1;
	GeeHashMap* _tmp33_;
	TubaWidgetsAccountRow** _tmp34_;
	gint _tmp34__length1;
	TubaWidgetsAccountRow** widget_collection;
	gint widget_collection_length1;
	gint _widget_collection_size_;
	gint widget_it;
	TubaWidgetsAccountRow* _tmp35_;
	TubaWidgetsAccountRow* widget;
	TubaWidgetsAccountRow* _tmp36_;
	GeeHashMap* _tmp37_;
	TubaWidgetsAccountRow* _tmp38_;
	TubaAPIAccount* _tmp39_;
	TubaAPIAccount* _tmp40_;
	const gchar* _tmp41_;
	const gchar* _tmp42_;
	gpointer _tmp43_;
	TubaAPIRelationship* _tmp44_;
	GError* _inner_error0_;
};

static gint TubaDialogsCollection_private_offset;
static gpointer tuba_dialogs_collection_parent_class = NULL;
VALA_EXTERN TubaAccountStore* tuba_accounts;

VALA_EXTERN GType tuba_dialogs_collection_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaDialogsCollection, g_object_unref)
VALA_EXTERN GType tuba_entity_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaEntity, g_object_unref)
VALA_EXTERN GType tuba_api_collection_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAPICollection, g_object_unref)
VALA_EXTERN TubaDialogsCollection* tuba_dialogs_collection_new (TubaAPICollection* collection);
VALA_EXTERN TubaDialogsCollection* tuba_dialogs_collection_construct (GType object_type,
                                                          TubaAPICollection* collection);
VALA_EXTERN const gchar* tuba_api_collection_get_name (TubaAPICollection* self);
VALA_EXTERN const gchar* tuba_api_collection_get_url (TubaAPICollection* self);
VALA_EXTERN GType tuba_api_collection_tag_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAPICollectionTag, g_object_unref)
VALA_EXTERN TubaAPICollectionTag* tuba_api_collection_get_tag (TubaAPICollection* self);
VALA_EXTERN const gchar* tuba_api_collection_tag_get_name (TubaAPICollectionTag* self);
VALA_EXTERN const gchar* tuba_api_collection_get_description (TubaAPICollection* self);
VALA_EXTERN GType tuba_widgets_markup_view_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaWidgetsMarkupView, g_object_unref)
VALA_EXTERN TubaWidgetsMarkupView* tuba_widgets_markup_view_new (void);
VALA_EXTERN TubaWidgetsMarkupView* tuba_widgets_markup_view_construct (GType object_type);
VALA_EXTERN void tuba_widgets_markup_view_set_content (TubaWidgetsMarkupView* self,
                                           const gchar* value);
static void tuba_dialogs_collection_on_copy_clicked (TubaDialogsCollection* self);
static void _tuba_dialogs_collection_on_copy_clicked_gtk_button_clicked (GtkButton* _sender,
                                                                  gpointer self);
static void tuba_dialogs_collection_on_vadjustment_changed (TubaDialogsCollection* self,
                                                     GtkAdjustment* vadjustment);
static void _tuba_dialogs_collection_on_vadjustment_changed_gtk_adjustment_value_changed (GtkAdjustment* _sender,
                                                                                   gpointer self);
VALA_EXTERN GType tuba_api_collection_item_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAPICollectionItem, g_object_unref)
VALA_EXTERN GeeArrayList* tuba_api_collection_get_items (TubaAPICollection* self);
static void tuba_dialogs_collection_gather_accounts (TubaDialogsCollection* self,
                                              TubaAPICollection* collection,
                                              GAsyncReadyCallback _callback_,
                                              gpointer _user_data_);
static void tuba_dialogs_collection_gather_accounts_finish (TubaDialogsCollection* self,
                                                     GAsyncResult* _res_,
                                                     GError** error);
static void tuba_dialogs_collection_gather_accounts_data_free (gpointer _data);
static gboolean tuba_dialogs_collection_gather_accounts_co (TubaDialogsCollectionGatherAccountsData* _data_);
VALA_EXTERN GType tuba_widgets_account_row_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaWidgetsAccountRow, g_object_unref)
static Block20Data* block20_data_ref (Block20Data* _data20_);
static void block20_data_unref (void * _userdata_);
VALA_EXTERN const gchar* tuba_api_collection_get_account_id (TubaAPICollection* self);
static void _g_free0_ (gpointer var);
static gboolean __lambda45_ (Block20Data* _data20_,
                      TubaAPICollectionItem* e);
VALA_EXTERN const gchar* tuba_api_collection_item_get_account_id (TubaAPICollectionItem* self);
static void _vala_array_add7 (gchar** * array,
                       gint* length,
                       gint* size,
                       gchar* value);
static void _vala_array_add8 (gchar** * array,
                       gint* length,
                       gint* size,
                       gchar* value);
VALA_EXTERN const gchar* tuba_api_collection_item_get_state (TubaAPICollectionItem* self);
static gboolean ___lambda45__gee_forall_func (gpointer g,
                                       gpointer self);
VALA_EXTERN GType tuba_request_v2_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaRequestV2, g_object_unref)
VALA_EXTERN GType tuba_request_v2_method_get_type (void) G_GNUC_CONST ;
VALA_EXTERN GType tuba_account_store_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAccountStore, g_object_unref)
VALA_EXTERN GType tuba_api_account_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAPIAccount, g_object_unref)
VALA_EXTERN GType tuba_instance_account_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaInstanceAccount, g_object_unref)
VALA_EXTERN TubaInstanceAccount* tuba_account_store_get_active (TubaAccountStore* self);
VALA_EXTERN TubaRequestV2* tuba_request_v2_new (const gchar* url,
                                    TubaRequestV2Method method);
VALA_EXTERN TubaRequestV2* tuba_request_v2_construct (GType object_type,
                                          const gchar* url,
                                          TubaRequestV2Method method);
VALA_EXTERN void tuba_request_v2_set_account (TubaRequestV2* self,
                                  TubaInstanceAccount* value);
VALA_EXTERN void tuba_request_v2_exec (TubaRequestV2* self,
                           GAsyncReadyCallback _callback_,
                           gpointer _user_data_);
VALA_EXTERN GQuark tuba_oopsie_quark (void);
VALA_EXTERN GType tuba_oopsie_get_type (void) G_GNUC_CONST ;
VALA_EXTERN GInputStream* tuba_request_v2_exec_finish (TubaRequestV2* self,
                                           GAsyncResult* _res_,
                                           SoupMessageHeaders** response_headers,
                                           GError** error);
static void tuba_dialogs_collection_gather_accounts_ready (GObject* source_object,
                                                    GAsyncResult* _res_,
                                                    gpointer _user_data_);
VALA_EXTERN void tuba_network_get_parser_from_inputstream_async (GInputStream* in_stream,
                                                     GCancellable* cancellable,
                                                     GAsyncReadyCallback _callback_,
                                                     gpointer _user_data_);
VALA_EXTERN JsonParser* tuba_network_get_parser_from_inputstream_finish (GAsyncResult* _res_,
                                                             GError** error);
VALA_EXTERN void tuba_network_parse_array (JsonParser* parser,
                               TubaNetworkNodeCallback cb,
                               gpointer cb_target,
                               GDestroyNotify cb_target_destroy_notify,
                               GError** error);
static void __lambda46_ (Block20Data* _data20_,
                  JsonNode* node,
                  GError** error);
VALA_EXTERN TubaAPIAccount* tuba_api_account_from (JsonNode* node,
                                       GError** error);
VALA_EXTERN TubaWidgetsAccountRow* tuba_widgets_account_row_new (TubaAPIAccount* account,
                                                     gboolean open_only);
VALA_EXTERN TubaWidgetsAccountRow* tuba_widgets_account_row_construct (GType object_type,
                                                           TubaAPIAccount* account,
                                                           gboolean open_only);
VALA_EXTERN void tuba_widgets_account_row_add_followers_and_verified_link (TubaWidgetsAccountRow* self);
static void _vala_array_add9 (TubaWidgetsAccountRow** * array,
                       gint* length,
                       gint* size,
                       TubaWidgetsAccountRow* value);
VALA_EXTERN const gchar* tuba_api_account_get_id (TubaAPIAccount* self);
VALA_EXTERN void tuba_widgets_account_row_add (TubaWidgetsAccountRow* self,
                                   GtkWidget* widget);
VALA_EXTERN void tuba_widgets_account_row_add_rs_button (TubaWidgetsAccountRow* self,
                                             gboolean from_acc);
static void ___lambda46__tuba_network_node_callback (JsonNode* node,
                                              gpointer self,
                                              GError** error);
VALA_EXTERN GType tuba_api_relationship_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAPIRelationship, g_object_unref)
VALA_EXTERN void tuba_api_relationship_request_many (gchar** ids,
                                         gint ids_length1,
                                         GAsyncReadyCallback _callback_,
                                         gpointer _user_data_);
VALA_EXTERN GeeHashMap* tuba_api_relationship_request_many_finish (GAsyncResult* _res_,
                                                       GError** error);
VALA_EXTERN TubaAPIAccount* tuba_widgets_account_row_get_account (TubaWidgetsAccountRow* self);
VALA_EXTERN void tuba_widgets_account_row_set_rs (TubaWidgetsAccountRow* self,
                                      TubaAPIRelationship* value);
VALA_EXTERN void tuba_utils_host_copy (const gchar* str);
static void tuba_dialogs_collection_finalize (GObject * obj);
static GType tuba_dialogs_collection_get_type_once (void);
static void _vala_array_destroy (gpointer array,
                          gssize array_length,
                          GDestroyNotify destroy_func);
static void _vala_array_free (gpointer array,
                       gssize array_length,
                       GDestroyNotify destroy_func);

static inline gpointer
tuba_dialogs_collection_get_instance_private (TubaDialogsCollection* self)
{
	return G_STRUCT_MEMBER_P (self, TubaDialogsCollection_private_offset);
}

static const gchar*
string_to_string (const gchar* self)
{
	const gchar* result;
	g_return_val_if_fail (self != NULL, NULL);
	result = self;
	return result;
}

static gpointer
_g_object_ref0 (gpointer self)
{
	return self ? g_object_ref (self) : NULL;
}

static void
_tuba_dialogs_collection_on_copy_clicked_gtk_button_clicked (GtkButton* _sender,
                                                             gpointer self)
{
	tuba_dialogs_collection_on_copy_clicked ((TubaDialogsCollection*) self);
}

static void
_tuba_dialogs_collection_on_vadjustment_changed_gtk_adjustment_value_changed (GtkAdjustment* _sender,
                                                                              gpointer self)
{
	tuba_dialogs_collection_on_vadjustment_changed ((TubaDialogsCollection*) self, _sender);
}

TubaDialogsCollection*
tuba_dialogs_collection_construct (GType object_type,
                                   TubaAPICollection* collection)
{
	TubaDialogsCollection * self = NULL;
	const gchar* _tmp0_;
	const gchar* _tmp1_;
	const gchar* _tmp2_;
	const gchar* _tmp3_;
	gchar* _tmp4_;
	gint _tmp5_ = 0;
	GtkBox* content_box = NULL;
	GtkBox* _tmp6_ = NULL;
	GtkBox* _tmp7_;
	const gchar* _tmp8_;
	const gchar* _tmp9_;
	gchar* _tmp10_;
	gchar** _tmp11_;
	GtkLabel* _tmp12_ = NULL;
	GtkLabel* _tmp13_;
	TubaAPICollectionTag* _tmp14_;
	TubaAPICollectionTag* _tmp15_;
	const gchar* _tmp40_;
	const gchar* _tmp41_;
	GtkScrolledWindow* scrolled_window = NULL;
	GtkBox* _tmp48_;
	GtkWidget* _tmp49_;
	AdwClamp* _tmp50_ = NULL;
	GtkScrolledWindow* _tmp51_ = NULL;
	GtkWidget* _tmp52_;
	AdwToastOverlay* _tmp53_ = NULL;
	AdwToolbarView* toolbar_view = NULL;
	AdwToastOverlay* _tmp54_;
	GtkWidget* _tmp55_;
	AdwToolbarView* _tmp56_ = NULL;
	AdwHeaderBar* _tmp57_ = NULL;
	GtkButton* copy_btn = NULL;
	gchar* _tmp58_;
	gchar** _tmp59_;
	GtkButton* _tmp60_ = NULL;
	AdwHeaderBar* _tmp61_;
	AdwHeaderBar* _tmp62_;
	GtkAdjustment* _tmp63_;
	GtkAdjustment* _tmp64_;
	GeeArrayList* _tmp65_;
	GeeArrayList* _tmp66_;
	gint _tmp67_;
	gint _tmp68_;
	GeeArrayList* _tmp69_;
	GeeArrayList* _tmp70_;
	gint _tmp71_;
	gint _tmp72_;
	gchar* _tmp73_;
	AdwPreferencesGroup* _tmp74_ = NULL;
	GtkBox* _tmp75_;
	AdwPreferencesGroup* _tmp76_;
	gchar* _tmp77_;
	AdwPreferencesGroup* _tmp78_ = NULL;
	GtkBox* _tmp79_;
	AdwPreferencesGroup* _tmp80_;
	g_return_val_if_fail (collection != NULL, NULL);
	self = (TubaDialogsCollection*) g_object_new (object_type, NULL);
	_tmp0_ = tuba_api_collection_get_name (collection);
	_tmp1_ = _tmp0_;
	adw_dialog_set_title ((AdwDialog*) self, _tmp1_);
	_tmp2_ = tuba_api_collection_get_url (collection);
	_tmp3_ = _tmp2_;
	_tmp4_ = g_strdup (_tmp3_);
	_g_free0 (self->priv->collection_url);
	self->priv->collection_url = _tmp4_;
	adw_dialog_set_content_width ((AdwDialog*) self, 600);
	adw_dialog_set_content_height ((AdwDialog*) self, 600);
	_tmp5_ = 12;
	_tmp6_ = (GtkBox*) gtk_box_new (GTK_ORIENTATION_VERTICAL, 12);
	gtk_widget_set_margin_bottom ((GtkWidget*) _tmp6_, _tmp5_);
	gtk_widget_set_margin_top ((GtkWidget*) _tmp6_, _tmp5_);
	gtk_widget_set_margin_start ((GtkWidget*) _tmp6_, 6);
	gtk_widget_set_margin_end ((GtkWidget*) _tmp6_, 6);
	g_object_ref_sink (_tmp6_);
	content_box = _tmp6_;
	_tmp7_ = content_box;
	_tmp8_ = tuba_api_collection_get_name (collection);
	_tmp9_ = _tmp8_;
	_tmp10_ = g_strdup ("title-1");
	_tmp11_ = g_new0 (gchar*, 1 + 1);
	_tmp11_[0] = _tmp10_;
	_tmp12_ = (GtkLabel*) gtk_label_new (_tmp9_);
	gtk_widget_set_css_classes ((GtkWidget*) _tmp12_, _tmp11_);
	_tmp11_ = (_vala_array_free (_tmp11_, 1, (GDestroyNotify) g_free), NULL);
	gtk_label_set_wrap (_tmp12_, TRUE);
	gtk_label_set_wrap_mode (_tmp12_, PANGO_WRAP_WORD_CHAR);
	gtk_widget_set_halign ((GtkWidget*) _tmp12_, GTK_ALIGN_CENTER);
	g_object_ref_sink (_tmp12_);
	_tmp13_ = _tmp12_;
	gtk_box_append (_tmp7_, (GtkWidget*) _tmp13_);
	_g_object_unref0 (_tmp13_);
	_tmp14_ = tuba_api_collection_get_tag (collection);
	_tmp15_ = _tmp14_;
	if (_tmp15_ != NULL) {
		gchar* _tmp16_ = NULL;
		TubaAPICollectionTag* _tmp17_;
		TubaAPICollectionTag* _tmp18_;
		const gchar* _tmp19_;
		const gchar* _tmp20_;
		gchar* tag = NULL;
		gchar* _tmp32_;
		GtkBox* _tmp33_;
		const gchar* _tmp34_;
		gchar* _tmp35_;
		gchar* _tmp36_;
		gchar** _tmp37_;
		GtkLabel* _tmp38_ = NULL;
		GtkLabel* _tmp39_;
		_tmp17_ = tuba_api_collection_get_tag (collection);
		_tmp18_ = _tmp17_;
		_tmp19_ = tuba_api_collection_tag_get_name (_tmp18_);
		_tmp20_ = _tmp19_;
		if (g_str_has_prefix (_tmp20_, "#")) {
			TubaAPICollectionTag* _tmp21_;
			TubaAPICollectionTag* _tmp22_;
			const gchar* _tmp23_;
			const gchar* _tmp24_;
			gchar* _tmp25_;
			_tmp21_ = tuba_api_collection_get_tag (collection);
			_tmp22_ = _tmp21_;
			_tmp23_ = tuba_api_collection_tag_get_name (_tmp22_);
			_tmp24_ = _tmp23_;
			_tmp25_ = g_strdup (_tmp24_);
			_g_free0 (_tmp16_);
			_tmp16_ = _tmp25_;
		} else {
			TubaAPICollectionTag* _tmp26_;
			TubaAPICollectionTag* _tmp27_;
			const gchar* _tmp28_;
			const gchar* _tmp29_;
			const gchar* _tmp30_;
			gchar* _tmp31_;
			_tmp26_ = tuba_api_collection_get_tag (collection);
			_tmp27_ = _tmp26_;
			_tmp28_ = tuba_api_collection_tag_get_name (_tmp27_);
			_tmp29_ = _tmp28_;
			_tmp30_ = string_to_string (_tmp29_);
			_tmp31_ = g_strconcat ("#", _tmp30_, NULL);
			_g_free0 (_tmp16_);
			_tmp16_ = _tmp31_;
		}
		_tmp32_ = _tmp16_;
		_tmp16_ = NULL;
		tag = _tmp32_;
		_tmp33_ = content_box;
		_tmp34_ = tag;
		_tmp35_ = g_strdup ("profile-role");
		_tmp36_ = g_strdup ("tuba-circular");
		_tmp37_ = g_new0 (gchar*, 2 + 1);
		_tmp37_[0] = _tmp35_;
		_tmp37_[1] = _tmp36_;
		_tmp38_ = (GtkLabel*) gtk_label_new (_tmp34_);
		gtk_widget_set_css_classes ((GtkWidget*) _tmp38_, _tmp37_);
		_tmp37_ = (_vala_array_free (_tmp37_, 2, (GDestroyNotify) g_free), NULL);
		gtk_label_set_wrap (_tmp38_, TRUE);
		gtk_label_set_wrap_mode (_tmp38_, PANGO_WRAP_WORD_CHAR);
		gtk_widget_set_halign ((GtkWidget*) _tmp38_, GTK_ALIGN_CENTER);
		g_object_ref_sink (_tmp38_);
		_tmp39_ = _tmp38_;
		gtk_box_append (_tmp33_, (GtkWidget*) _tmp39_);
		_g_object_unref0 (_tmp39_);
		_g_free0 (tag);
		_g_free0 (_tmp16_);
	}
	_tmp40_ = tuba_api_collection_get_description (collection);
	_tmp41_ = _tmp40_;
	if (_tmp41_ != NULL) {
		TubaWidgetsMarkupView* markupview = NULL;
		const gchar* _tmp42_;
		const gchar* _tmp43_;
		gchar* _tmp44_;
		TubaWidgetsMarkupView* _tmp45_ = NULL;
		GtkBox* _tmp46_;
		TubaWidgetsMarkupView* _tmp47_;
		_tmp42_ = tuba_api_collection_get_description (collection);
		_tmp43_ = _tmp42_;
		_tmp44_ = g_strdup (_tmp43_);
		_tmp45_ = tuba_widgets_markup_view_new ();
		tuba_widgets_markup_view_set_content (_tmp45_, _tmp44_);
		_g_free0 (_tmp44_);
		g_object_ref_sink (_tmp45_);
		markupview = _tmp45_;
		_tmp46_ = content_box;
		_tmp47_ = markupview;
		gtk_box_append (_tmp46_, (GtkWidget*) _tmp47_);
		_g_object_unref0 (markupview);
	}
	_tmp48_ = content_box;
	_tmp49_ = _g_object_ref0 ((GtkWidget*) _tmp48_);
	_tmp50_ = (AdwClamp*) adw_clamp_new ();
	adw_clamp_set_child (_tmp50_, _tmp49_);
	_g_object_unref0 (_tmp49_);
	adw_clamp_set_tightening_threshold (_tmp50_, 100);
	gtk_widget_set_valign ((GtkWidget*) _tmp50_, GTK_ALIGN_START);
	g_object_ref_sink (_tmp50_);
	_tmp51_ = (GtkScrolledWindow*) gtk_scrolled_window_new ();
	gtk_widget_set_hexpand ((GtkWidget*) _tmp51_, TRUE);
	gtk_widget_set_vexpand ((GtkWidget*) _tmp51_, TRUE);
	gtk_scrolled_window_set_child (_tmp51_, (GtkWidget*) _tmp50_);
	_g_object_unref0 (_tmp50_);
	g_object_ref_sink (_tmp51_);
	scrolled_window = _tmp51_;
	_tmp52_ = _g_object_ref0 ((GtkWidget*) scrolled_window);
	_tmp53_ = (AdwToastOverlay*) adw_toast_overlay_new ();
	gtk_widget_set_vexpand ((GtkWidget*) _tmp53_, TRUE);
	gtk_widget_set_hexpand ((GtkWidget*) _tmp53_, TRUE);
	adw_toast_overlay_set_child (_tmp53_, _tmp52_);
	_g_object_unref0 (_tmp52_);
	g_object_ref_sink (_tmp53_);
	_g_object_unref0 (self->priv->toast_overlay);
	self->priv->toast_overlay = _tmp53_;
	_tmp54_ = self->priv->toast_overlay;
	_tmp55_ = _g_object_ref0 ((GtkWidget*) _tmp54_);
	_tmp56_ = (AdwToolbarView*) adw_toolbar_view_new ();
	adw_toolbar_view_set_content (_tmp56_, _tmp55_);
	_g_object_unref0 (_tmp55_);
	g_object_ref_sink (_tmp56_);
	toolbar_view = _tmp56_;
	_tmp57_ = (AdwHeaderBar*) adw_header_bar_new ();
	adw_header_bar_set_show_title (_tmp57_, FALSE);
	g_object_ref_sink (_tmp57_);
	_g_object_unref0 (self->priv->headerbar);
	self->priv->headerbar = _tmp57_;
	_tmp58_ = g_strdup ("suggested-action");
	_tmp59_ = g_new0 (gchar*, 1 + 1);
	_tmp59_[0] = _tmp58_;
	_tmp60_ = (GtkButton*) gtk_button_new_with_label (_ ("Copy URL"));
	gtk_widget_set_css_classes ((GtkWidget*) _tmp60_, _tmp59_);
	_tmp59_ = (_vala_array_free (_tmp59_, 1, (GDestroyNotify) g_free), NULL);
	g_object_ref_sink (_tmp60_);
	copy_btn = _tmp60_;
	g_signal_connect_object (copy_btn, "clicked", (GCallback) _tuba_dialogs_collection_on_copy_clicked_gtk_button_clicked, self, 0);
	_tmp61_ = self->priv->headerbar;
	adw_header_bar_pack_end (_tmp61_, (GtkWidget*) copy_btn);
	_tmp62_ = self->priv->headerbar;
	adw_toolbar_view_add_top_bar (toolbar_view, (GtkWidget*) _tmp62_);
	adw_dialog_set_child ((AdwDialog*) self, (GtkWidget*) toolbar_view);
	_tmp63_ = gtk_scrolled_window_get_vadjustment (scrolled_window);
	_tmp64_ = _tmp63_;
	g_signal_connect_object (_tmp64_, "value-changed", (GCallback) _tuba_dialogs_collection_on_vadjustment_changed_gtk_adjustment_value_changed, self, 0);
	_tmp65_ = tuba_api_collection_get_items (collection);
	_tmp66_ = _tmp65_;
	_tmp67_ = gee_abstract_collection_get_size ((GeeAbstractCollection*) _tmp66_);
	_tmp68_ = _tmp67_;
	_tmp69_ = tuba_api_collection_get_items (collection);
	_tmp70_ = _tmp69_;
	_tmp71_ = gee_abstract_collection_get_size ((GeeAbstractCollection*) _tmp70_);
	_tmp72_ = _tmp71_;
	_tmp73_ = g_strdup_printf (ngettext ("%d Member", "%d Members", (gulong) _tmp68_), _tmp72_);
	_tmp74_ = (AdwPreferencesGroup*) adw_preferences_group_new ();
	adw_preferences_group_set_title (_tmp74_, _tmp73_);
	_g_free0 (_tmp73_);
	g_object_ref_sink (_tmp74_);
	_g_object_unref0 (self->priv->member_group);
	self->priv->member_group = _tmp74_;
	_tmp75_ = content_box;
	_tmp76_ = self->priv->member_group;
	gtk_box_append (_tmp75_, (GtkWidget*) _tmp76_);
	_tmp77_ = g_strdup (_ ("Created By"));
	_tmp78_ = (AdwPreferencesGroup*) adw_preferences_group_new ();
	adw_preferences_group_set_title (_tmp78_, _tmp77_);
	_g_free0 (_tmp77_);
	g_object_ref_sink (_tmp78_);
	_g_object_unref0 (self->priv->author_group);
	self->priv->author_group = _tmp78_;
	_tmp79_ = content_box;
	_tmp80_ = self->priv->author_group;
	gtk_box_append (_tmp79_, (GtkWidget*) _tmp80_);
	tuba_dialogs_collection_gather_accounts (self, collection, NULL, NULL);
	_g_object_unref0 (copy_btn);
	_g_object_unref0 (toolbar_view);
	_g_object_unref0 (scrolled_window);
	_g_object_unref0 (content_box);
	return self;
}

TubaDialogsCollection*
tuba_dialogs_collection_new (TubaAPICollection* collection)
{
	return tuba_dialogs_collection_construct (TUBA_DIALOGS_TYPE_COLLECTION, collection);
}

static void
tuba_dialogs_collection_gather_accounts_data_free (gpointer _data)
{
	TubaDialogsCollectionGatherAccountsData* _data_;
	_data_ = _data;
	_g_object_unref0 (_data_->self);
	g_slice_free (TubaDialogsCollectionGatherAccountsData, _data_);
}

static void
tuba_dialogs_collection_gather_accounts (TubaDialogsCollection* self,
                                         TubaAPICollection* collection,
                                         GAsyncReadyCallback _callback_,
                                         gpointer _user_data_)
{
	TubaDialogsCollectionGatherAccountsData* _data_;
	TubaDialogsCollection* _tmp0_;
	TubaAPICollection* _tmp1_;
	g_return_if_fail (self != NULL);
	g_return_if_fail (collection != NULL);
	_data_ = g_slice_new0 (TubaDialogsCollectionGatherAccountsData);
	_data_->_async_result = g_task_new (G_OBJECT (self), NULL, _callback_, _user_data_);
	g_task_set_task_data (_data_->_async_result, _data_, tuba_dialogs_collection_gather_accounts_data_free);
	_tmp0_ = _g_object_ref0 (self);
	_data_->self = _tmp0_;
	_tmp1_ = _g_object_ref0 (collection);
	_g_object_unref0 (_data_->collection);
	_data_->collection = _tmp1_;
	tuba_dialogs_collection_gather_accounts_co (_data_);
}

static void
tuba_dialogs_collection_gather_accounts_finish (TubaDialogsCollection* self,
                                                GAsyncResult* _res_,
                                                GError** error)
{
	TubaDialogsCollectionGatherAccountsData* _data_;
	_data_ = g_task_propagate_pointer (G_TASK (_res_), error);
	if (NULL == _data_) {
		return;
	}
}

static Block20Data*
block20_data_ref (Block20Data* _data20_)
{
	g_atomic_int_inc (&_data20_->_ref_count_);
	return _data20_;
}

static void
block20_data_unref (void * _userdata_)
{
	Block20Data* _data20_;
	_data20_ = (Block20Data*) _userdata_;
	if (g_atomic_int_dec_and_test (&_data20_->_ref_count_)) {
		TubaDialogsCollection* self;
		self = _data20_->self;
		_data20_->widgets = (_vala_array_free (_data20_->widgets, _data20_->widgets_length1, (GDestroyNotify) g_object_unref), NULL);
		_g_hash_table_unref0 (_data20_->states);
		_data20_->account_ids = (_vala_array_free (_data20_->account_ids, _data20_->account_ids_length1, (GDestroyNotify) g_free), NULL);
		_data20_->accounts_arr = (_vala_array_free (_data20_->accounts_arr, _data20_->accounts_arr_length1, (GDestroyNotify) g_free), NULL);
		_g_object_unref0 (_data20_->collection);
		_g_object_unref0 (self);
		g_slice_free (Block20Data, _data20_);
	}
}

static void
_g_free0_ (gpointer var)
{
	var = (g_free (var), NULL);
}

static void
_vala_array_add7 (gchar** * array,
                  gint* length,
                  gint* size,
                  gchar* value)
{
	if ((*length) == (*size)) {
		*size = (*size) ? (2 * (*size)) : 4;
		*array = g_renew (gchar*, *array, (*size) + 1);
	}
	(*array)[(*length)++] = value;
	(*array)[*length] = NULL;
}

static void
_vala_array_add8 (gchar** * array,
                  gint* length,
                  gint* size,
                  gchar* value)
{
	if ((*length) == (*size)) {
		*size = (*size) ? (2 * (*size)) : 4;
		*array = g_renew (gchar*, *array, (*size) + 1);
	}
	(*array)[(*length)++] = value;
	(*array)[*length] = NULL;
}

static gboolean
__lambda45_ (Block20Data* _data20_,
             TubaAPICollectionItem* e)
{
	TubaDialogsCollection* self;
	const gchar* _tmp0_;
	const gchar* _tmp1_;
	const gchar* _tmp2_;
	gchar* _tmp3_;
	const gchar* _tmp4_;
	const gchar* _tmp5_;
	gchar* _tmp6_;
	GHashTable* _tmp7_;
	const gchar* _tmp8_;
	const gchar* _tmp9_;
	gchar* _tmp10_;
	const gchar* _tmp11_;
	const gchar* _tmp12_;
	gchar* _tmp13_;
	gboolean result;
	self = _data20_->self;
	g_return_val_if_fail (e != NULL, FALSE);
	_tmp0_ = tuba_api_collection_item_get_account_id (e);
	_tmp1_ = _tmp0_;
	_tmp2_ = string_to_string (_tmp1_);
	_tmp3_ = g_strconcat ("id[]=", _tmp2_, NULL);
	_vala_array_add7 (&_data20_->accounts_arr, &_data20_->accounts_arr_length1, &_data20_->_accounts_arr_size_, _tmp3_);
	_tmp4_ = tuba_api_collection_item_get_account_id (e);
	_tmp5_ = _tmp4_;
	_tmp6_ = g_strdup (_tmp5_);
	_vala_array_add8 (&_data20_->account_ids, &_data20_->account_ids_length1, &_data20_->_account_ids_size_, _tmp6_);
	_tmp7_ = _data20_->states;
	_tmp8_ = tuba_api_collection_item_get_account_id (e);
	_tmp9_ = _tmp8_;
	_tmp10_ = g_strdup (_tmp9_);
	_tmp11_ = tuba_api_collection_item_get_state (e);
	_tmp12_ = _tmp11_;
	_tmp13_ = g_strdup (_tmp12_);
	g_hash_table_insert (_tmp7_, _tmp10_, _tmp13_);
	result = TRUE;
	_g_object_unref0 (e);
	return result;
}

static gboolean
___lambda45__gee_forall_func (gpointer g,
                              gpointer self)
{
	gboolean result;
	result = __lambda45_ (self, (TubaAPICollectionItem*) g);
	return result;
}

static gchar*
_vala_g_strjoinv (const gchar* separator,
                  gchar** str_array,
                  gint str_array_length1)
{
	gboolean _tmp0_ = FALSE;
	gchar* result;
	if (separator == NULL) {
		separator = "";
	}
	if (str_array != NULL) {
		gboolean _tmp1_ = FALSE;
		if (str_array_length1 > 0) {
			_tmp1_ = TRUE;
		} else {
			gboolean _tmp2_ = FALSE;
			if (str_array_length1 == -1) {
				const gchar* _tmp3_;
				_tmp3_ = str_array[0];
				_tmp2_ = _tmp3_ != NULL;
			} else {
				_tmp2_ = FALSE;
			}
			_tmp1_ = _tmp2_;
		}
		_tmp0_ = _tmp1_;
	} else {
		_tmp0_ = FALSE;
	}
	if (_tmp0_) {
		gint i = 0;
		gsize len = 0UL;
		gint _tmp16_;
		gint _tmp17_;
		const gchar* res = NULL;
		void* _tmp18_;
		const gchar* _tmp19_ = NULL;
		const gchar* _tmp20_;
		void* ptr = NULL;
		const gchar* _tmp22_;
		void* _tmp23_;
		const gchar* _tmp33_;
		len = (gsize) 1;
		{
			gboolean _tmp4_ = FALSE;
			i = 0;
			_tmp4_ = TRUE;
			while (TRUE) {
				gboolean _tmp6_ = FALSE;
				gboolean _tmp7_ = FALSE;
				gint _tmp10_ = 0;
				const gchar* _tmp11_;
				if (!_tmp4_) {
					gint _tmp5_;
					_tmp5_ = i;
					i = _tmp5_ + 1;
				}
				_tmp4_ = FALSE;
				if (str_array_length1 != -1) {
					_tmp7_ = i < str_array_length1;
				} else {
					_tmp7_ = FALSE;
				}
				if (_tmp7_) {
					_tmp6_ = TRUE;
				} else {
					gboolean _tmp8_ = FALSE;
					if (str_array_length1 == -1) {
						const gchar* _tmp9_;
						_tmp9_ = str_array[i];
						_tmp8_ = _tmp9_ != NULL;
					} else {
						_tmp8_ = FALSE;
					}
					_tmp6_ = _tmp8_;
				}
				if (!_tmp6_) {
					break;
				}
				_tmp11_ = str_array[i];
				if (_tmp11_ != NULL) {
					const gchar* _tmp12_;
					gint _tmp13_;
					gint _tmp14_;
					_tmp12_ = str_array[i];
					_tmp13_ = strlen ((const gchar*) _tmp12_);
					_tmp14_ = _tmp13_;
					_tmp10_ = _tmp14_;
				} else {
					_tmp10_ = 0;
				}
				len += (gsize) _tmp10_;
			}
		}
		if (i == 0) {
			gchar* _tmp15_;
			_tmp15_ = g_strdup ("");
			result = _tmp15_;
			return result;
		}
		str_array_length1 = i;
		_tmp16_ = strlen ((const gchar*) separator);
		_tmp17_ = _tmp16_;
		len += (gsize) (_tmp17_ * (i - 1));
		_tmp18_ = g_malloc (len);
		res = _tmp18_;
		_tmp20_ = str_array[0];
		if (_tmp20_ != NULL) {
			const gchar* _tmp21_;
			_tmp21_ = str_array[0];
			_tmp19_ = (const gchar*) _tmp21_;
		} else {
			_tmp19_ = "";
		}
		_tmp22_ = res;
		_tmp23_ = g_stpcpy ((void*) _tmp22_, _tmp19_);
		ptr = _tmp23_;
		{
			gboolean _tmp24_ = FALSE;
			i = 1;
			_tmp24_ = TRUE;
			while (TRUE) {
				void* _tmp26_;
				void* _tmp27_;
				const gchar* _tmp28_ = NULL;
				const gchar* _tmp29_;
				void* _tmp31_;
				void* _tmp32_;
				if (!_tmp24_) {
					gint _tmp25_;
					_tmp25_ = i;
					i = _tmp25_ + 1;
				}
				_tmp24_ = FALSE;
				if (!(i < str_array_length1)) {
					break;
				}
				_tmp26_ = ptr;
				_tmp27_ = g_stpcpy (_tmp26_, (const gchar*) separator);
				ptr = _tmp27_;
				_tmp29_ = str_array[i];
				if (_tmp29_ != NULL) {
					const gchar* _tmp30_;
					_tmp30_ = str_array[i];
					_tmp28_ = (const gchar*) _tmp30_;
				} else {
					_tmp28_ = "";
				}
				_tmp31_ = ptr;
				_tmp32_ = g_stpcpy (_tmp31_, _tmp28_);
				ptr = _tmp32_;
			}
		}
		_tmp33_ = res;
		res = NULL;
		result = (gchar*) _tmp33_;
		return result;
	} else {
		gchar* _tmp34_;
		_tmp34_ = g_strdup ("");
		result = _tmp34_;
		return result;
	}
}

static void
tuba_dialogs_collection_gather_accounts_ready (GObject* source_object,
                                               GAsyncResult* _res_,
                                               gpointer _user_data_)
{
	TubaDialogsCollectionGatherAccountsData* _data_;
	_data_ = _user_data_;
	_data_->_source_object_ = source_object;
	_data_->_res_ = _res_;
	tuba_dialogs_collection_gather_accounts_co (_data_);
}

static void
_vala_array_add9 (TubaWidgetsAccountRow** * array,
                  gint* length,
                  gint* size,
                  TubaWidgetsAccountRow* value)
{
	if ((*length) == (*size)) {
		*size = (*size) ? (2 * (*size)) : 4;
		*array = g_renew (TubaWidgetsAccountRow*, *array, (*size) + 1);
	}
	(*array)[(*length)++] = value;
	(*array)[*length] = NULL;
}

static void
__lambda46_ (Block20Data* _data20_,
             JsonNode* node,
             GError** error)
{
	TubaDialogsCollection* self;
	TubaAPIAccount* acc = NULL;
	TubaAPIAccount* _tmp0_;
	TubaWidgetsAccountRow* widget = NULL;
	TubaWidgetsAccountRow* _tmp1_;
	TubaWidgetsAccountRow* _tmp2_;
	TubaWidgetsAccountRow* _tmp3_;
	TubaWidgetsAccountRow* _tmp4_;
	gboolean _tmp5_ = FALSE;
	const gchar* _tmp6_;
	const gchar* _tmp7_;
	const gchar* _tmp8_;
	const gchar* _tmp9_;
	const gchar* _tmp26_;
	const gchar* _tmp27_;
	TubaAccountStore* _tmp28_;
	TubaInstanceAccount* _tmp29_;
	TubaInstanceAccount* _tmp30_;
	const gchar* _tmp31_;
	const gchar* _tmp32_;
	GError* _inner_error0_ = NULL;
	self = _data20_->self;
	g_return_if_fail (node != NULL);
	_tmp0_ = tuba_api_account_from (node, &_inner_error0_);
	acc = _tmp0_;
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
		g_propagate_error (error, _inner_error0_);
		return;
	}
	_tmp1_ = tuba_widgets_account_row_new (acc, FALSE);
	g_object_ref_sink (_tmp1_);
	widget = _tmp1_;
	_tmp2_ = widget;
	tuba_widgets_account_row_add_followers_and_verified_link (_tmp2_);
	_tmp3_ = widget;
	_tmp4_ = _g_object_ref0 (_tmp3_);
	_vala_array_add9 (&_data20_->widgets, &_data20_->widgets_length1, &_data20_->_widgets_size_, _tmp4_);
	_tmp6_ = tuba_api_account_get_id (acc);
	_tmp7_ = _tmp6_;
	_tmp8_ = tuba_api_collection_get_account_id (_data20_->collection);
	_tmp9_ = _tmp8_;
	if (g_strcmp0 (_tmp7_, _tmp9_) == 0) {
		_tmp5_ = !_data20_->did_author;
	} else {
		_tmp5_ = FALSE;
	}
	if (_tmp5_) {
		AdwPreferencesGroup* _tmp10_;
		TubaWidgetsAccountRow* _tmp11_;
		_tmp10_ = self->priv->author_group;
		_tmp11_ = widget;
		adw_preferences_group_add (_tmp10_, (GtkWidget*) _tmp11_);
		_data20_->did_author = TRUE;
	} else {
		GHashTable* _tmp12_;
		const gchar* _tmp13_;
		const gchar* _tmp14_;
		gconstpointer _tmp15_;
		AdwPreferencesGroup* _tmp24_;
		TubaWidgetsAccountRow* _tmp25_;
		_tmp12_ = _data20_->states;
		_tmp13_ = tuba_api_account_get_id (acc);
		_tmp14_ = _tmp13_;
		_tmp15_ = g_hash_table_lookup (_tmp12_, _tmp14_);
		if (g_strcmp0 ((const gchar*) _tmp15_, "pending") == 0) {
			TubaWidgetsAccountRow* _tmp16_;
			gchar* _tmp17_;
			gchar* _tmp18_;
			gchar* _tmp19_;
			gchar** _tmp20_;
			gchar* _tmp21_;
			GtkLabel* _tmp22_ = NULL;
			GtkLabel* _tmp23_;
			_tmp16_ = widget;
			_tmp17_ = g_strdup ("warning");
			_tmp18_ = g_strdup ("profile-role");
			_tmp19_ = g_strdup ("tuba-circular");
			_tmp20_ = g_new0 (gchar*, 3 + 1);
			_tmp20_[0] = _tmp17_;
			_tmp20_[1] = _tmp18_;
			_tmp20_[2] = _tmp19_;
			_tmp21_ = g_strdup (_ ("Pending"));
			_tmp22_ = (GtkLabel*) gtk_label_new (_ ("Pending"));
			gtk_widget_set_css_classes ((GtkWidget*) _tmp22_, _tmp20_);
			_tmp20_ = (_vala_array_free (_tmp20_, 3, (GDestroyNotify) g_free), NULL);
			gtk_widget_set_tooltip_text ((GtkWidget*) _tmp22_, _tmp21_);
			_g_free0 (_tmp21_);
			gtk_label_set_ellipsize (_tmp22_, PANGO_ELLIPSIZE_END);
			gtk_widget_set_valign ((GtkWidget*) _tmp22_, GTK_ALIGN_CENTER);
			g_object_ref_sink (_tmp22_);
			_tmp23_ = _tmp22_;
			tuba_widgets_account_row_add (_tmp16_, (GtkWidget*) _tmp23_);
			_g_object_unref0 (_tmp23_);
		}
		_tmp24_ = self->priv->member_group;
		_tmp25_ = widget;
		adw_preferences_group_add (_tmp24_, (GtkWidget*) _tmp25_);
	}
	_tmp26_ = tuba_api_account_get_id (acc);
	_tmp27_ = _tmp26_;
	_tmp28_ = tuba_accounts;
	_tmp29_ = tuba_account_store_get_active (_tmp28_);
	_tmp30_ = _tmp29_;
	_tmp31_ = tuba_api_account_get_id ((TubaAPIAccount*) _tmp30_);
	_tmp32_ = _tmp31_;
	if (g_strcmp0 (_tmp27_, _tmp32_) != 0) {
		TubaWidgetsAccountRow* _tmp33_;
		_tmp33_ = widget;
		tuba_widgets_account_row_add_rs_button (_tmp33_, FALSE);
	}
	_g_object_unref0 (widget);
	_g_object_unref0 (acc);
}

static void
___lambda46__tuba_network_node_callback (JsonNode* node,
                                         gpointer self,
                                         GError** error)
{
	__lambda46_ (self, node, error);
}

static gboolean
tuba_dialogs_collection_gather_accounts_co (TubaDialogsCollectionGatherAccountsData* _data_)
{
	switch (_data_->_state_) {
		case 0:
		goto _state_0;
		case 1:
		goto _state_1;
		case 2:
		goto _state_2;
		case 3:
		goto _state_3;
		default:
		g_assert_not_reached ();
	}
	_state_0:
	_data_->_data20_ = g_slice_new0 (Block20Data);
	_data_->_data20_->_ref_count_ = 1;
	_data_->_data20_->self = g_object_ref (_data_->self);
	_g_object_unref0 (_data_->_data20_->collection);
	_data_->_data20_->collection = _data_->collection;
	_data_->_data20_->_async_data_ = _data_;
	_data_->_tmp0_ = tuba_api_collection_get_account_id (_data_->_data20_->collection);
	_data_->_tmp1_ = _data_->_tmp0_;
	_data_->_tmp2_ = string_to_string (_data_->_tmp1_);
	_data_->_tmp3_ = g_strconcat ("id[]=", _data_->_tmp2_, NULL);
	_data_->_tmp4_ = g_new0 (gchar*, 1 + 1);
	_data_->_tmp4_[0] = _data_->_tmp3_;
	_data_->_data20_->accounts_arr = _data_->_tmp4_;
	_data_->_data20_->accounts_arr_length1 = 1;
	_data_->_data20_->_accounts_arr_size_ = _data_->_data20_->accounts_arr_length1;
	_data_->_tmp5_ = tuba_api_collection_get_account_id (_data_->_data20_->collection);
	_data_->_tmp6_ = _data_->_tmp5_;
	_data_->_tmp7_ = g_strdup (_data_->_tmp6_);
	_data_->_tmp8_ = g_new0 (gchar*, 1 + 1);
	_data_->_tmp8_[0] = _data_->_tmp7_;
	_data_->_data20_->account_ids = _data_->_tmp8_;
	_data_->_data20_->account_ids_length1 = 1;
	_data_->_data20_->_account_ids_size_ = _data_->_data20_->account_ids_length1;
	_data_->_tmp9_ = g_str_hash;
	_data_->_tmp10_ = g_str_equal;
	_data_->_tmp11_ = g_hash_table_new_full (_data_->_tmp9_, _data_->_tmp10_, _g_free0_, _g_free0_);
	_data_->_data20_->states = _data_->_tmp11_;
	_data_->_tmp12_ = tuba_api_collection_get_items (_data_->_data20_->collection);
	_data_->_tmp13_ = _data_->_tmp12_;
	gee_abstract_collection_foreach ((GeeAbstractCollection*) _data_->_tmp13_, ___lambda45__gee_forall_func, _data_->_data20_);
	_data_->_tmp14_ = _data_->_data20_->accounts_arr;
	_data_->_tmp14__length1 = _data_->_data20_->accounts_arr_length1;
	_data_->_tmp15_ = _vala_g_strjoinv ("&", _data_->_tmp14_, (gint) _data_->_tmp14__length1);
	_data_->_tmp16_ = _data_->_tmp15_;
	_data_->_tmp17_ = string_to_string (_data_->_tmp16_);
	_data_->_tmp18_ = g_strconcat ("/api/v1/accounts?", _data_->_tmp17_, NULL);
	_data_->_tmp19_ = _data_->_tmp18_;
	_data_->_tmp20_ = tuba_accounts;
	_data_->_tmp21_ = tuba_account_store_get_active (_data_->_tmp20_);
	_data_->_tmp22_ = _data_->_tmp21_;
	_data_->_tmp23_ = _g_object_ref0 (_data_->_tmp22_);
	_data_->_tmp24_ = NULL;
	_data_->_tmp24_ = tuba_request_v2_new (_data_->_tmp19_, TUBA_REQUEST_V2_METHOD_GET);
	tuba_request_v2_set_account (_data_->_tmp24_, _data_->_tmp23_);
	_g_object_unref0 (_data_->_tmp23_);
	_data_->_tmp25_ = _data_->_tmp24_;
	_g_free0 (_data_->_tmp19_);
	_g_free0 (_data_->_tmp16_);
	_data_->req = _data_->_tmp25_;
	_data_->_tmp26_ = _data_->req;
	_data_->_state_ = 1;
	tuba_request_v2_exec (_data_->_tmp26_, tuba_dialogs_collection_gather_accounts_ready, _data_);
	return FALSE;
	_state_1:
	_data_->_tmp27_ = tuba_request_v2_exec_finish (_data_->_tmp26_, _data_->_res_, NULL, &_data_->_inner_error0_);
	_data_->in_stream = _data_->_tmp27_;
	if (G_UNLIKELY (_data_->_inner_error0_ != NULL)) {
		g_task_return_error (_data_->_async_result, _data_->_inner_error0_);
		_g_object_unref0 (_data_->req);
		block20_data_unref (_data_->_data20_);
		_data_->_data20_ = NULL;
		g_object_unref (_data_->_async_result);
		return FALSE;
	}
	_data_->_tmp28_ = g_new0 (TubaWidgetsAccountRow*, 0 + 1);
	_data_->_data20_->widgets = _data_->_tmp28_;
	_data_->_data20_->widgets_length1 = 0;
	_data_->_data20_->_widgets_size_ = _data_->_data20_->widgets_length1;
	_data_->_tmp29_ = _data_->in_stream;
	_data_->_state_ = 2;
	tuba_network_get_parser_from_inputstream_async (_data_->_tmp29_, NULL, tuba_dialogs_collection_gather_accounts_ready, _data_);
	return FALSE;
	_state_2:
	_data_->_tmp30_ = tuba_network_get_parser_from_inputstream_finish (_data_->_res_, &_data_->_inner_error0_);
	_data_->parser = _data_->_tmp30_;
	if (G_UNLIKELY (_data_->_inner_error0_ != NULL)) {
		g_task_return_error (_data_->_async_result, _data_->_inner_error0_);
		_g_object_unref0 (_data_->in_stream);
		_g_object_unref0 (_data_->req);
		block20_data_unref (_data_->_data20_);
		_data_->_data20_ = NULL;
		g_object_unref (_data_->_async_result);
		return FALSE;
	}
	_data_->_data20_->did_author = FALSE;
	_data_->_tmp31_ = _data_->parser;
	tuba_network_parse_array (_data_->_tmp31_, ___lambda46__tuba_network_node_callback, block20_data_ref (_data_->_data20_), block20_data_unref, &_data_->_inner_error0_);
	if (G_UNLIKELY (_data_->_inner_error0_ != NULL)) {
		g_task_return_error (_data_->_async_result, _data_->_inner_error0_);
		_g_object_unref0 (_data_->parser);
		_g_object_unref0 (_data_->in_stream);
		_g_object_unref0 (_data_->req);
		block20_data_unref (_data_->_data20_);
		_data_->_data20_ = NULL;
		g_object_unref (_data_->_async_result);
		return FALSE;
	}
	_data_->_tmp32_ = _data_->_data20_->account_ids;
	_data_->_tmp32__length1 = _data_->_data20_->account_ids_length1;
	_data_->_state_ = 3;
	tuba_api_relationship_request_many (_data_->_tmp32_, (gint) _data_->_tmp32__length1, tuba_dialogs_collection_gather_accounts_ready, _data_);
	return FALSE;
	_state_3:
	_data_->_tmp33_ = tuba_api_relationship_request_many_finish (_data_->_res_, &_data_->_inner_error0_);
	_data_->relationships = _data_->_tmp33_;
	if (G_UNLIKELY (_data_->_inner_error0_ != NULL)) {
		g_task_return_error (_data_->_async_result, _data_->_inner_error0_);
		_g_object_unref0 (_data_->parser);
		_g_object_unref0 (_data_->in_stream);
		_g_object_unref0 (_data_->req);
		block20_data_unref (_data_->_data20_);
		_data_->_data20_ = NULL;
		g_object_unref (_data_->_async_result);
		return FALSE;
	}
	_data_->_tmp34_ = _data_->_data20_->widgets;
	_data_->_tmp34__length1 = _data_->_data20_->widgets_length1;
	{
		_data_->widget_collection_length1 = 0;
		_data_->_widget_collection_size_ = 0;
		_data_->widget_collection = _data_->_tmp34_;
		_data_->widget_collection_length1 = _data_->_tmp34__length1;
		for (_data_->widget_it = 0; _data_->widget_it < _data_->widget_collection_length1; _data_->widget_it = _data_->widget_it + 1) {
			_data_->_tmp35_ = _g_object_ref0 (_data_->widget_collection[_data_->widget_it]);
			_data_->widget = _data_->_tmp35_;
			{
				_data_->_tmp36_ = _data_->widget;
				_data_->_tmp37_ = _data_->relationships;
				_data_->_tmp38_ = _data_->widget;
				_data_->_tmp39_ = tuba_widgets_account_row_get_account (_data_->_tmp38_);
				_data_->_tmp40_ = _data_->_tmp39_;
				_data_->_tmp41_ = tuba_api_account_get_id (_data_->_tmp40_);
				_data_->_tmp42_ = _data_->_tmp41_;
				_data_->_tmp43_ = gee_abstract_map_get ((GeeAbstractMap*) _data_->_tmp37_, _data_->_tmp42_);
				_data_->_tmp44_ = (TubaAPIRelationship*) _data_->_tmp43_;
				tuba_widgets_account_row_set_rs (_data_->_tmp36_, _data_->_tmp44_);
				_g_object_unref0 (_data_->_tmp44_);
				_g_object_unref0 (_data_->widget);
			}
		}
	}
	_g_object_unref0 (_data_->relationships);
	_g_object_unref0 (_data_->parser);
	_g_object_unref0 (_data_->in_stream);
	_g_object_unref0 (_data_->req);
	block20_data_unref (_data_->_data20_);
	_data_->_data20_ = NULL;
	g_task_return_pointer (_data_->_async_result, _data_, NULL);
	if (_data_->_state_ != 0) {
		while (!g_task_get_completed (_data_->_async_result)) {
			g_main_context_iteration (g_task_get_context (_data_->_async_result), TRUE);
		}
	}
	g_object_unref (_data_->_async_result);
	return FALSE;
}

static void
tuba_dialogs_collection_on_vadjustment_changed (TubaDialogsCollection* self,
                                                GtkAdjustment* vadjustment)
{
	AdwHeaderBar* _tmp0_;
	gdouble _tmp1_;
	gdouble _tmp2_;
	g_return_if_fail (self != NULL);
	g_return_if_fail (vadjustment != NULL);
	_tmp0_ = self->priv->headerbar;
	_tmp1_ = gtk_adjustment_get_value (vadjustment);
	_tmp2_ = _tmp1_;
	adw_header_bar_set_show_title (_tmp0_, _tmp2_ > ((gdouble) 10));
}

static void
tuba_dialogs_collection_on_copy_clicked (TubaDialogsCollection* self)
{
	const gchar* _tmp0_;
	AdwToastOverlay* _tmp1_;
	AdwToast* _tmp2_ = NULL;
	g_return_if_fail (self != NULL);
	_tmp0_ = self->priv->collection_url;
	tuba_utils_host_copy (_tmp0_);
	_tmp1_ = self->priv->toast_overlay;
	_tmp2_ = adw_toast_new (_ ("Copied url to clipboard"));
	adw_toast_set_timeout (_tmp2_, (guint) 5);
	adw_toast_overlay_add_toast (_tmp1_, _tmp2_);
}

static void
tuba_dialogs_collection_class_init (TubaDialogsCollectionClass * klass,
                                    gpointer klass_data)
{
	tuba_dialogs_collection_parent_class = g_type_class_peek_parent (klass);
	g_type_class_adjust_private_offset (klass, &TubaDialogsCollection_private_offset);
	G_OBJECT_CLASS (klass)->finalize = tuba_dialogs_collection_finalize;
}

static void
tuba_dialogs_collection_instance_init (TubaDialogsCollection * self,
                                       gpointer klass)
{
	self->priv = tuba_dialogs_collection_get_instance_private (self);
}

static void
tuba_dialogs_collection_finalize (GObject * obj)
{
	TubaDialogsCollection * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TUBA_DIALOGS_TYPE_COLLECTION, TubaDialogsCollection);
	g_debug ("Collection.vala:9: Destroying Collection");
	_g_object_unref0 (self->priv->headerbar);
	_g_object_unref0 (self->priv->member_group);
	_g_object_unref0 (self->priv->author_group);
	_g_object_unref0 (self->priv->toast_overlay);
	_g_free0 (self->priv->collection_url);
	G_OBJECT_CLASS (tuba_dialogs_collection_parent_class)->finalize (obj);
}

 G_GNUC_NO_INLINE static GType
tuba_dialogs_collection_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (TubaDialogsCollectionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) tuba_dialogs_collection_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (TubaDialogsCollection), 0, (GInstanceInitFunc) tuba_dialogs_collection_instance_init, NULL };
	GType tuba_dialogs_collection_type_id;
	tuba_dialogs_collection_type_id = g_type_register_static (adw_dialog_get_type (), "TubaDialogsCollection", &g_define_type_info, G_TYPE_FLAG_NONE);
	TubaDialogsCollection_private_offset = g_type_add_instance_private (tuba_dialogs_collection_type_id, sizeof (TubaDialogsCollectionPrivate));
	return tuba_dialogs_collection_type_id;
}

GType
tuba_dialogs_collection_get_type (void)
{
	static GType tuba_dialogs_collection_type_id__once = 0;
	if (g_once_init_enter_pointer (&tuba_dialogs_collection_type_id__once)) {
		GType tuba_dialogs_collection_type_id;
		tuba_dialogs_collection_type_id = tuba_dialogs_collection_get_type_once ();
		g_once_init_leave_pointer (&tuba_dialogs_collection_type_id__once, tuba_dialogs_collection_type_id);
	}
	return tuba_dialogs_collection_type_id__once;
}

static void
_vala_array_destroy (gpointer array,
                     gssize array_length,
                     GDestroyNotify destroy_func)
{
	if ((array != NULL) && (destroy_func != NULL)) {
		gssize i;
		for (i = 0; i < array_length; i = i + 1) {
			if (((gpointer*) array)[i] != NULL) {
				destroy_func (((gpointer*) array)[i]);
			}
		}
	}
}

static void
_vala_array_free (gpointer array,
                  gssize array_length,
                  GDestroyNotify destroy_func)
{
	_vala_array_destroy (array, array_length, destroy_func);
	g_free (array);
}

